{{
  
  //  load the shared lib
  //  gSystem->Load("lib/mars.so") ; 
  
  MTaskList *tlist = new MTaskList() ; 
  MParList  *plist = new MParList() ; 

  //
  
  MCerPhotEvt *phevt = new MCerPhotEvt() ; 

  plist->AddToList( phevt ) ; 
  
  //MReadCT1Ascii *readct1 = new MReadCT1Ascii("/hd10/www/Anal_MAGIC/MCCT1_99_ga20.dat") ; 

  MReadCT1Ascii *readct1 = new MReadCT1Ascii("/hd10/www/Anal_MAGIC/CT1_99_on1.dat") ; 

  cout << readct1->PreProcess(plist) << endl ; 

  Int_t icount = 0 ; 
  MCamDisplay display(0) ; 

  //display.SetAutoScale(kFALSE) ; 

  while ( readct1->Process() == kTRUE )
    {
      cout << "Event: " << icount++  << endl  ;
      
      if (icount >= 45 ) { 
	
	display->Draw( phevt )  ; 

	gClient->HandleInput();   
	if(getchar()=='q')
	  break;
	
	
	phevt->CleanLevel1() ; 
	phevt->CleanLevel2() ; 
	display->Draw( phevt )  ; 
	gClient->HandleInput();   
	if(getchar()=='q')
	  break;

	phevt->CleanLevel3() ; 
	
	display->Draw( phevt )  ; 
	gClient->HandleInput();   
	if(getchar()=='q')
	  break;

      } 
     phevt->Print() ;

    } 

  cout << readct1->PostProcess() << endl ; 
}}

